==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/ca.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeria",
    "Could not move \"{file}\", target exists" : "No s'ha pugut moure \"{file}\", el destí ja existeix",
    "Could not move \"{file}\"" : "No s'ha pogut moure \"{file}\"",
    "Invalid server url" : "URL del servidor invàlida",
    "Gallery view" : "Vista de galeria",
    "Could not load the description" : "no s'ha pogut carregar la descripció",
    "Could not load the description: " : "no s'ha pogut carregar la descripció:",
    "Copyright" : "Drets de reproducció",
    "Could not load the copyright notice: " : "No es va carregar l'avis sobre drets de reproducció",
    "Copyright notice" : "Avis sobre drets de reproducció",
    "Link to copyright document" : "Enllaç a document sobre drets de reproducció",
    "This application may not work properly on your browser." : "Aquesta aplicació pot not funcionar correctament en el teu navegador",
    "For an improved experience, please install one of the following alternatives" : "Per una millor experiència, millor instal·lar alguna de les següents alternatives",
    "Your browser is not supported!" : "El vostre navegador no està soportat!",
    "please install one of the following alternatives" : "per favor instal·lar una de les següents alternatives",
    "Album cannot be shown" : "L'album no es pot mostrar",
    "No media files found" : "No s\\'han trobat fitxers multimèdia",
    "Configuration error" : "Error de configuració",
    "New" : "Nou",
    "Hide Album" : "Amaga album",
    "Could not hide album" : "No es pot amagar l'album",
    "Error loading slideshow template" : "Error en carregar la plantilla de presentació amb diapositives",
    "Next" : "Següent",
    "Play" : "Reprodueix",
    "Pause" : "Pausa",
    "Previous" : "Anterior",
    "Close" : "Tanca",
    "Download" : "Descàrrega",
    "Delete" : "Esborra",
    "\"{name}\" is an invalid file name." : "\"{name}\" no es un fitxer vàlid.",
    "File name cannot be empty." : "El nom del fitxer no pot ser buit.",
    "Upload" : "Puja",
    "Error" : "Error",
    "Error while sharing" : "Error en compartir",
    "Error while unsharing" : "Error en deixar de compartir",
    "Error while changing permissions" : "Error en canviar els permisos",
    "Shared with you and the group {group} by {owner}" : "Compartit amb vos i amb el grup {group} per {owner}",
    "Shared with you by {owner}" : "Compartit amb vos per {owner}",
    "Share with users or groups …" : "Comparteix amb usuaris o grups ...",
    "Share with users, groups or remote users …" : "Comparteix amb usuaris, grups o usuaris remots ...",
    "Share" : "Comparteix",
    "Share link" : "Comparteix l'enllaç",
    "The public link will expire no later than {days} days after it is created" : "L'enllaç públic tindrà venciment abans de {days} dies després de crear-lo",
    "Link" : "Enllaç",
    "Password protect" : "Protegir amb contrasenya",
    "Password" : "Contrasenya",
    "Choose a password for the public link" : "Escolliu una contrasenya per l'enllaç públic",
    "Allow editing" : "Permetre edició",
    "Email link to person" : "Enllaç per correu electrónic amb la persona",
    "Send" : "Envia",
    "Set expiration date" : "Estableix la data de venciment",
    "Expiration" : "Expiració",
    "Expiration date" : "Data de venciment",
    "An error occured. Please try again" : "S'ha produït un error. Si us plau, intenta-ho de nou",
    "Adding user..." : "Afegint usuari...",
    "group" : "grup",
    "remote" : "remot",
    "Resharing is not allowed" : "No es permet compartir de nou",
    "Unshare" : "Deixa de compartir",
    "notify by email" : "notifica per correu electrònic",
    "can share" : "pot compartir",
    "can edit" : "pot editar",
    "access control" : "control d'accés",
    "create" : "crea",
    "change" : "canvi",
    "delete" : "elimina",
    "Password protected" : "Protegeix amb contrasenya",
    "Error unsetting expiration date" : "Error en eliminar la data de venciment",
    "Error setting expiration date" : "Error en establir la data de venciment",
    "Sending ..." : "Enviant...",
    "Email sent" : "El correu electrónic s'ha enviat",
    "Warning" : "Avís",
    "This share is password-protected" : "Aquest compartit està protegit amb contrasenya",
    "The password is wrong. Try again." : "la contrasenya és incorrecta. Intenteu-ho de nou.",
    "Sort by date" : "Ordena per data",
    "Sort by name" : "Ordena per nom",
    "Cancel upload" : "Cancel·la la pujada",
    "Album information" : "Informació de l'àlbum",
    "File list" : "Llista de fitxers",
    "Sorry, this file could not be found." : "Ho sentim, aquest fitxer no s'ha trobat.",
    "Reasons might be:" : "Les raons podrien ser:",
    "the file was removed" : "l'arxiu ha estat eliminat",
    "the file is corrupt" : "L'arxiu està corrupte",
    "Possible reasons for the problem:" : "Posible motiu del problema: ",
    "For more information, please contact your friendly ownCloud administrator." : "Per a més informació pots contactar el teu amigable administrador Nextcloud.",
    "Sorry, this link doesn't seem to work anymore." : "Ho sento, aquest enllaç no sembla funcionar més.",
    "the item was removed" : "l'element ha estat eliminat",
    "the link has expired" : "l'enllaç ha expirat",
    "sharing is disabled" : "s'ha desactivat la compartició",
    "Add to your Nextcloud" : "Afegir al teu Nextcloud",
    "Picture view" : "Mostra fotos"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/ca.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeria",
    "Could not move \"{file}\", target exists" : "No s'ha pugut moure \"{file}\", el destí ja existeix",
    "Could not move \"{file}\"" : "No s'ha pogut moure \"{file}\"",
    "Invalid server url" : "URL del servidor invàlida",
    "Could not load the description" : "no s'ha pogut carregar la descripció",
    "Could not load the description: " : "no s'ha pogut carregar la descripció:",
    "Copyright" : "Drets de reproducció",
    "Could not load the copyright notice: " : "No es va carregar l'avis sobre drets de reproducció",
    "Copyright notice" : "Avis sobre drets de reproducció",
    "Link to copyright document" : "Enllaç a document sobre drets de reproducció",
    "This application may not work properly on your browser." : "Aquesta aplicació pot not funcionar correctament en el teu navegador",
    "For an improved experience, please install one of the following alternatives" : "Per una millor experiència, millor instal·lar alguna de les següents alternatives",
    "Your browser is not supported!" : "El vostre navegador no està soportat!",
    "please install one of the following alternatives" : "per favor instal·lar una de les següents alternatives",
    "Album cannot be shown" : "L'album no es pot mostrar",
    "No media files found" : "No s\\'han trobat fitxers multimèdia",
    "Configuration error" : "Error de configuració",
    "New" : "Nou",
    "Hide Album" : "Amaga album",
    "Could not hide album" : "No es pot amagar l'album",
    "Error loading slideshow template" : "Error en carregar la plantilla de presentació amb diapositives",
    "Next" : "Següent",
    "Play" : "Reprodueix",
    "Pause" : "Pausa",
    "Previous" : "Anterior",
    "Close" : "Tanca",
    "Download" : "Descàrrega",
    "Delete" : "Esborra",
    "\"{name}\" is an invalid file name." : "\"{name}\" no es un fitxer vàlid.",
    "File name cannot be empty." : "El nom del fitxer no pot ser buit.",
    "Upload" : "Puja",
    "Error" : "Error",
    "Error while sharing" : "Error en compartir",
    "Error while unsharing" : "Error en deixar de compartir",
    "Error while changing permissions" : "Error en canviar els permisos",
    "Shared with you and the group {group} by {owner}" : "Compartit amb vos i amb el grup {group} per {owner}",
    "Shared with you by {owner}" : "Compartit amb vos per {owner}",
    "Share with users or groups …" : "Comparteix amb usuaris o grups ...",
    "Share with users, groups or remote users …" : "Comparteix amb usuaris, grups o usuaris remots ...",
    "Share" : "Comparteix",
    "Share link" : "Comparteix l'enllaç",
    "The public link will expire no later than {days} days after it is created" : "L'enllaç públic tindrà venciment abans de {days} dies després de crear-lo",
    "Link" : "Enllaç",
    "Password protect" : "Protegir amb contrasenya",
    "Password" : "Contrasenya",
    "Choose a password for the public link" : "Escolliu una contrasenya per l'enllaç públic",
    "Allow editing" : "Permetre edició",
    "Email link to person" : "Enllaç per correu electrónic amb la persona",
    "Send" : "Envia",
    "Set expiration date" : "Estableix la data de venciment",
    "Expiration" : "Expiració",
    "Expiration date" : "Data de venciment",
    "An error occured. Please try again" : "S'ha produït un error. Si us plau, intenta-ho de nou",
    "Adding user..." : "Afegint usuari...",
    "group" : "grup",
    "remote" : "remot",
    "Resharing is not allowed" : "No es permet compartir de nou",
    "Unshare" : "Deixa de compartir",
    "notify by email" : "notifica per correu electrònic",
    "can share" : "pot compartir",
    "can edit" : "pot editar",
    "access control" : "control d'accés",
    "create" : "crea",
    "change" : "canvi",
    "delete" : "elimina",
    "Password protected" : "Protegeix amb contrasenya",
    "Error unsetting expiration date" : "Error en eliminar la data de venciment",
    "Error setting expiration date" : "Error en establir la data de venciment",
    "Sending ..." : "Enviant...",
    "Email sent" : "El correu electrónic s'ha enviat",
    "Warning" : "Avís",
    "This share is password-protected" : "Aquest compartit està protegit amb contrasenya",
    "The password is wrong. Try again." : "la contrasenya és incorrecta. Intenteu-ho de nou.",
    "Sort by date" : "Ordena per data",
    "Sort by name" : "Ordena per nom",
    "Cancel upload" : "Cancel·la la pujada",
    "Album information" : "Informació de l'àlbum",
    "File list" : "Llista de fitxers",
    "Sorry, this file could not be found." : "Ho sentim, aquest fitxer no s'ha trobat.",
    "Reasons might be:" : "Les raons podrien ser:",
    "the file was removed" : "l'arxiu ha estat eliminat",
    "the file is corrupt" : "L'arxiu està corrupte",
    "Possible reasons for the problem:" : "Posible motiu del problema: ",
    "Sorry, this link doesn't seem to work anymore." : "Ho sento, aquest enllaç no sembla funcionar més.",
    "the item was removed" : "l'element ha estat eliminat",
    "the link has expired" : "l'enllaç ha expirat",
    "sharing is disabled" : "s'ha desactivat la compartició",
    "Add to your Nextcloud" : "Afegir al teu Nextcloud",
    "Picture view" : "Mostra fotos",
    "Gallery view" : "Vista de galeria"
},
"nplurals=2; plural=(n != 1);");
